@@ -2,6 +2,7 @@ package DTL::Fast::Tag;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Parser';
 
+use DTL::Fast;
 use DTL::Fast::Template;
 
 sub new
@@ -14,6 +15,7 @@ sub new
     $DTL::Fast::Template::CURRENT_TEMPLATE->{'modules'}->{$proto} //= $proto->VERSION // DTL::Fast->VERSION;
     
     $kwargs{'parameter'} = $parameter;
+    
     return $proto->SUPER::new(%kwargs);
 }
 
@@ -54,5 +56,30 @@ sub parse_tag_chunk
     return $result;
 }
 
+# returns restored opening tag
+sub open_tag_syntax
+{
+    my ($self) = @_;
+    
+    return join( ' ',
+        grep(
+            $_
+            , (
+                '{%'
+                , $DTL::Fast::KNOWN_SLUGS{ref $self}
+                , $self->{'parameter'}
+                , '%}'
+            )
+        )
+    );
+}
+
+# returns restored opening tag
+sub open_tag_syntax_with_line_number
+{
+    my ($self) = @_;
+    return $self->open_tag_syntax().' at line '.($self->{'source_line'} // 'unknown');
+}
+
 
 1;
